class Socket{
    ws = null;  // websocket实例
    _alive = false; // 连接状态
    _params = null; // 把类的参数传入这里，方便调用
  
    /* 计时器 */
    _reconnect_timer = null;    // 重连计时器
    _heart_timer = null;    // 心跳计时器
    _message_func = null;   // 信息onmessage缓存方法
  
    /* 参数 */
    heartBeat = 60000;  // 心跳时间 60秒一次
    heartMsg = 'totaldata'; // 心跳信息
    reconnect = true; // 是否自动重连
    reconnectTime = 5000; // 重连间隔时间
    reconnectTimes = 10; // 重连次数
    constructor(params) {
        this._params = params
        this.init()
    }
  
    /* 初始化 */
    init() {
        // 重中之重，不然重连的时候会越来越快
        clearInterval(this._reconnect_timer);
        clearInterval(this._heart_timer);
    
        let params = this._params;
        
        let {url, port} = params;   // 设置连接路径
        let global_params = ['heartBeat', 'heartMsg', 'reconnect', 'reconnectTime', 'reconnectTimes'];
        
        // 定义全局变量
        Object.keys(params).forEach(key=>{
            if (global_params.indexOf(key) !== -1) {
                this[key] = params[key];
            }
        })
  
        let ws_url = port ? url + ':' + port : url;
        delete this.ws;
        this.ws = new WebSocket(ws_url);
        if(this._message_func) this.onmessage(this._message_func);
      
  
        // 默认绑定事件
        this.ws.onopen = () => { 
            this._alive = true; // 设置状态为开启
            clearInterval(this._reconnect_timer)
            this.onheartbeat(); // 连接后进入心跳状态
        }

        this.ws.onclose = () => { 
            
            this._alive = false;    // 设置状态为断开
            clearInterval(this._heart_timer)
    
            // 自动重连开启
            if (true == this.reconnect) {
                this.onreconnect(); // 断开后立刻重连
            }
        }
    }
  
    /* 心跳事件 */
    onheartbeat(func) {
        // 在连接状态下
        if(true == this._alive) {
            /* 心跳计时器 */
            this._heart_timer = setInterval(()=>{
                // 发送心跳信息
                this.send(this.heartMsg)
                func ? func(this) : false
            }, this.heartBeat)
        }
    }
  
    /* 重连事件 */
    onreconnect(func) {
        /* 重连间隔计时器 */
        this._reconnect_timer = setInterval(()=>{
            // 限制重连次数
            if(this.reconnectTimes <= 0){
                clearInterval(this._reconnect_timer)
                return; // 跳出函数之间的循环
				console.log('连接超时');
            }else{
                this.reconnectTimes--;  // 重连一次-1
				console.log('正在尝试重新连接');
            }
            
            this.init();    // 进入初始状态
            func ? func(this) : false
        },this.reconnectTime)
    }
  
    // 发送消息 
    send(text) {
        if(true == this._alive){
            text = typeof text == 'string' ?  text : JSON.stringify(text);
            this.ws.send(text);
            console.log('发送消息：', text)
        }
    }
  
    // 断开连接
    close() {
        if(true == this._alive){
            this.ws.close();
			console.log('服务器已断开');
        }
    }
  
    //接受消息
    onmessage(func, all = false) {
        this.ws.onmessage = data => {
            this._message_func = func;
            func(!all ? data.data : data);
        }
    }
  
    //websocket连接成功事件
    onopen(func) {
        this.ws.onopen = event => {
            this._alive = true;
            func ? func(event) : false;
			console.log('服务器已连接');
        }
    }
    // 关闭事件
    onclose(func) { 
        this.ws.onclose = event => {
            //设置状态为断开
            this._alive = false;
            clearInterval(this._heart_timer);
            // 自动重连开启
            if(true == this.reconnect){
                this.onreconnect(); // 断开后立刻重连
            }
            func ? func(event) : false;
        }
    }
    // 错误事件
    onerror(func) { 
        this.ws.onerror = event => {
            func ? func(event) : false
        }
    }
}
  
  //export default Socket;

var time = new Date();
var bytetimes = [time.toLocaleTimeString()];
var packettimes = [time.toLocaleTimeString()];
var bytetdata = {"send": [0], "recv": [0]};
var packetdata = {"send": [0], "recv": [0]};
var dom = document.getElementById('byted');
var myChart = echarts.init(dom, null, {
    renderer: 'canvas',
    useDirtyRect: false
});
var app = {};

var option;

option = {
    title: {
        text: '数据量(byte)'
    },
    tooltip: {
        trigger: 'axis',
        axisPointer: {
            type: 'cross',
            label: {
                backgroundColor: '#6a7985'
            }
        }
    },
    legend: {
        data: ['发送', '接收']
    },
    toolbox: {
        feature: {
            saveAsImage: {}
        }
    },
    grid: {
        left: '3%',
        right: '4%',
        bottom: '3%',
        containLabel: true
    },
    xAxis: [
        {
            type: 'category',
            boundaryGap: false,
            data: bytetimes
        }
    ],
    yAxis: [
        {
            type: 'value'
        }
    ],
    series: [
        {
            name: '发送',
            type: 'line',
            stack: 'Total',
            areaStyle: {},
            emphasis: {
                focus: 'series'
            },
            data: bytetdata.send
        },
        {
            name: '接收',
            type: 'line',
            stack: 'Total',
            areaStyle: {},
            emphasis: {
                focus: 'series'
            },
            data: bytetdata.recv
        }
    ]
};

if (option && typeof option === 'object') {
    myChart.setOption(option);
}

window.addEventListener('resize', myChart.resize);

var dom2 = document.getElementById('packet');
var myChart2 = echarts.init(dom2, null, {
    renderer: 'canvas',
    useDirtyRect: false
});
var app2 = {};

var option2;

option2 = {
    title: {
        text: '数据包数量(个)'
    },
    tooltip: {
        trigger: 'axis',
        axisPointer: {
            type: 'cross',
            label: {
                backgroundColor: '#6a7985'
            }
        }
    },
    legend: {
        data: ['发送', '接收']
    },
    toolbox: {
        feature: {
            saveAsImage: {}
        }
    },
    grid: {
        left: '3%',
        right: '4%',
        bottom: '3%',
        containLabel: true
    },
    xAxis: [
        {
            type: 'category',
            boundaryGap: false,
            data: packettimes
        }
    ],
    yAxis: [
        {
            type: 'value'
        }
    ],
    series: [
        {
            name: '发送',
            type: 'line',
            stack: 'Total',
            areaStyle: {},
            emphasis: {
                focus: 'series'
            },
            data: packetdata.send
        },
        {
            name: '接收',
            type: 'line',
            stack: 'Total',
            areaStyle: {},
            emphasis: {
                focus: 'series'
            },
            data: packetdata.recv
        }
    ]
};

if (option2 && typeof option2 === 'object') {
    myChart2.setOption(option2);
}

window.addEventListener('resize', myChart2.resize);

var dom3 = document.getElementById('mem');
var myChart3 = echarts.init(dom3, null, {
    renderer: 'canvas',
    useDirtyRect: false
});
var app = {};

var option3;

option3 = {
    series: [
        {
            type: 'gauge',
            center: ['50%', '60%'],
            startAngle: 200,
            endAngle: -20,
            min: 0,
            max: 100,
            splitNumber: 10,
            itemStyle: {
                color: '#FFAB91'
            },
            progress: {
                show: true,
                width: 30
            },
            pointer: {
                show: false
            },
            axisLine: {
                lineStyle: {
                    width: 30
                }
            },
            axisTick: {
                distance: -40,
                splitNumber: 5,
                lineStyle: {
                    width: 2,
                    color: '#999'
                }
            },
            splitLine: {
                distance: -48,
                length: 10,
                lineStyle: {
                    width: 2,
                    color: '#999'
                }
            },
            axisLabel: {
                distance: 8,
                color: '#999',
                fontSize: 10
            },
            anchor: {
                show: false
            },
            title: {
                show: false
            },
            detail: {
                valueAnimation: true,
                width: '60%',
                lineHeight: 40,
                borderRadius: 8,
                offsetCenter: [0, '-15%'],
                fontSize: 14,
                fontWeight: 'bolder',
                formatter: '{value} %',
                color: 'auto'
            },
            data: [
                {
                    value: 0
                }
            ]
        },
        {
            type: 'gauge',
            center: ['50%', '60%'],
            startAngle: 200,
            endAngle: -20,
            min: 0,
            max: 100,
            itemStyle: {
                color: '#FD7347'
            },
            progress: {
                show: true,
                width: 8
            },
            pointer: {
                show: false
            },
            axisLine: {
                show: false
            },
            axisTick: {
                show: false
            },
            splitLine: {
                show: false
            },
            axisLabel: {
                show: false
            },
            detail: {
                show: false
            },
            data: [
                {
                    value: 0
                }
            ]
        }
    ]
};
if (option3 && typeof option3 === 'object') {
    myChart3.setOption(option3);
}

window.addEventListener('resize', myChart3.resize);

var dom4 = document.getElementById('send');
        var myChart4 = echarts.init(dom4, null, {
            renderer: 'canvas',
            useDirtyRect: false
        });
var option4 = {
            title: {
                text: '发送的数据包(Sent)',
                subtext: '单位:byte',
                left: 'center'
            },
            tooltip: {
                trigger: 'item',
                formatter: '{a} <br/>{b} : {c} ({d}%)'
            },
            legend: {
                type: 'scroll',
                orient: 'vertical',
                right: 10,
                top: 20,
                bottom: 20
            },
            series: [
                {
                    name: '数据包类型',
                    type: 'pie',
                    radius: '55%',
                    center: ['40%', '50%'],
                    emphasis: {
                        itemStyle: {
                            shadowBlur: 10,
                            shadowOffsetX: 0,
                            shadowColor: 'rgba(0, 0, 0, 0.5)'
                        }
                    }
                }
            ]
        };
		var dom5 = document.getElementById('receive');
        var myChart5 = echarts.init(dom5, null, {
            renderer: 'canvas',
            useDirtyRect: false
        });
        var option5;
        option5 = {
            title: {
                text: '接收到的数据包(Received)',
                subtext: '单位:byte',
                left: 'center'
            },
            tooltip: {
                trigger: 'item',
                formatter: '{a} <br/>{b} : {c} ({d}%)'
            },
            legend: {
                type: 'scroll',
                orient: 'vertical',
                right: 10,
                top: 20,
                bottom: 20
            },
            series: [
                {
                    name: '数据包类型',
                    type: 'pie',
                    radius: '55%',
                    center: ['40%', '50%'],
                    emphasis: {
                        itemStyle: {
                            shadowBlur: 10,
                            shadowOffsetX: 0,
                            shadowColor: 'rgba(0, 0, 0, 0.5)'
                        }
                    }
                }
            ]
        };
var dom6 = document.getElementById('sendtimes');
        var myChart6 = echarts.init(dom6, null, {
            renderer: 'canvas',
            useDirtyRect: false
        });
        var app = {};

        var option6;

        option6 = {
            title: {
                text: '数据包发送次数'
            },
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            legend: {},
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'value',
                boundaryGap: [0, 0.01]
            },
            yAxis: {
                type: 'category'
            },
            series: [
                {
                    type: 'bar'
                },
            ]
        };
		 var dom7 = document.getElementById('recvtimes');
        var myChart7 = echarts.init(dom7, null, {
            renderer: 'canvas',
            useDirtyRect: false
        });
        var app = {};

        var option7;

        option7 = {
            title: {
                text: '数据包接收次数'
            },
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            legend: {},
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'value',
                boundaryGap: [0, 0.01]
            },
            yAxis: {
                type: 'category'
				},
            series: [
                {
                    type: 'bar',
					color: '#1C8878'
                },
            ]
        };
		var dom8 = document.getElementById('players');
var myChart8 = echarts.init(dom8, null, {
    renderer: 'canvas',
    useDirtyRect: false
});
var app = {};

var option8;

option8 = {
    series: [
        {
            type: 'gauge',
            center: ['50%', '60%'],
            startAngle: 200,
            endAngle: -20,
            min: 0,
            max: 100,
            splitNumber: 10,
            itemStyle: {
                color: '#21D56D'
            },
            progress: {
                show: true,
                width: 30
            },
            pointer: {
                show: false
            },
            axisLine: {
                lineStyle: {
                    width: 30
                }
            },
            axisTick: {
                distance: -40,
                splitNumber: 5,
                lineStyle: {
                    width: 2,
                    color: '#999'
                }
            },
            splitLine: {
                distance: -48,
                length: 10,
                lineStyle: {
                    width: 2,
                    color: '#999'
                }
            },
            axisLabel: {
                distance: 8,
                color: '#999',
                fontSize: 10
            },
            anchor: {
                show: false
            },
            title: {
                show: false
            },
            detail: {
                valueAnimation: true,
                width: '60%',
                lineHeight: 40,
                borderRadius: 8,
                offsetCenter: [0, '-15%'],
                fontSize: 14,
                fontWeight: 'bolder',
                formatter: '{value} 人',
                color: 'auto'
            },
            data: [
                {
                    value: 0
                }
            ]
        },
        {
            type: 'gauge',
            center: ['50%', '60%'],
            startAngle: 200,
            endAngle: -20,
            min: 0,
            max: 100,
            itemStyle: {
                color: '#18803A'
            },
            progress: {
                show: true,
                width: 8
            },
            pointer: {
                show: false
            },
            axisLine: {
                show: false
            },
            axisTick: {
                show: false
            },
            splitLine: {
                show: false
            },
            axisLabel: {
                show: false
            },
            detail: {
                show: false
            },
            data: [
                {
                    value: 0
                }
            ]
        }
    ]
};
if (option8 && typeof option8 === 'object') {
    myChart8.setOption(option8);
}

window.addEventListener('resize', myChart8.resize);